aboutsummaryrefslogtreecommitdiff
path: root/platform/linux-generic/include/odp_timer_internal.h
diff options
context:
space:
mode:
authorMatias Elo <matias.elo@nokia.com>2021-12-17 14:00:35 +0200
committerGitHub <noreply@github.com>2021-12-17 14:00:35 +0200
commitc3789c8e6ec34faee0b59080c1ab187cff1dc356 (patch)
treeb19561c2fdf7e26201237004b0344d21b0038ef2 /platform/linux-generic/include/odp_timer_internal.h
parent2ed1489ccc354300037bad2e718fe63cd6fdd7ba (diff)
parenta4f277eb71029ecf61c6b4dda7894d5e949c4852 (diff)
Merge ODP v1.33.0.0v1.33.0.0_DPDK_19.11
Merge ODP linux-generic v1.33.0.0 into linux-dpdk
Diffstat (limited to 'platform/linux-generic/include/odp_timer_internal.h')
-rw-r--r--platform/linux-generic/include/odp_timer_internal.h15
1 files changed, 7 insertions, 8 deletions
diff --git a/platform/linux-generic/include/odp_timer_internal.h b/platform/linux-generic/include/odp_timer_internal.h
index 435fa8b70..2a7173d29 100644
--- a/platform/linux-generic/include/odp_timer_internal.h
+++ b/platform/linux-generic/include/odp_timer_internal.h
@@ -1,4 +1,5 @@
/* Copyright (c) 2014-2018, Linaro Limited
+ * Copyright (c) 2021, Nokia
* All rights reserved.
*
* SPDX-License-Identifier: BSD-3-Clause
@@ -15,19 +16,18 @@
#include <odp/api/align.h>
#include <odp/api/debug.h>
-#include <odp_buffer_internal.h>
-#include <odp_pool_internal.h>
#include <odp/api/timer.h>
+
+#include <odp_event_internal.h>
#include <odp_global_data.h>
+#include <odp_pool_internal.h>
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wpedantic"
/**
* Internal Timeout header
*/
-typedef struct {
- /* common buffer header */
- odp_buffer_hdr_t buf_hdr;
+typedef struct ODP_ALIGNED_CACHE odp_timeout_hdr_t {
+ /* Common event header */
+ _odp_event_hdr_t event_hdr;
/* Requested expiration time */
uint64_t expiration;
@@ -39,7 +39,6 @@ typedef struct {
odp_timer_t timer;
} odp_timeout_hdr_t;
-#pragma GCC diagnostic pop
/* A larger decrement value should be used after receiving events compared to
* an 'empty' call. */